package com.mortals.xhx.module.site.web;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.OrderCol;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.common.code.OperTypeEnum;
import com.mortals.xhx.module.site.model.SiteMatterEntity;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.*;
import com.mortals.framework.model.Context;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.module.site.model.SiteMatterAssistEntity;
import com.mortals.xhx.module.site.service.SiteMatterAssistService;
import org.apache.commons.lang3.ArrayUtils;
import com.mortals.framework.util.StringUtils;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import java.util.Arrays;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import static com.mortals.framework.ap.SysConstains.*;
/**
*
* 辅助接件事项
*
* @author zxfei
* @date 2023-03-17
*/
@RestController
@RequestMapping("site/matter/assist")
public class SiteMatterAssistController extends BaseCRUDJsonBodyMappingController<SiteMatterAssistService,SiteMatterAssistEntity,Long> {

    @Autowired
    private ParamService paramService;

    public SiteMatterAssistController(){
        super.setModuleDesc( "辅助接件事项");
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        Map<String, String> suggest = new HashMap<>(2);
        suggest.put("0", "取消推荐");
        suggest.put("1", "推荐");
        this.addDict(model, "source", paramService.getParamBySecondOrganize("SiteMatter","source"));
        this.addDict(model,"suggest",suggest);
        super.init(model, context);
    }

    @Override
    protected void doListBefore(SiteMatterAssistEntity query, Map<String, Object> model, Context context) throws AppException {
        if (ObjectUtils.isEmpty(query.getOrderColList())) {
            query.setOrderColList(Arrays.asList(new OrderCol("suggest", OrderCol.DESCENDING), new OrderCol("viewsCount", OrderCol.DESCENDING)));
        } else {
            query.getOrderColList().add(0,new OrderCol("viewsCount", OrderCol.DESCENDING));
            query.getOrderColList().add(0,new OrderCol("suggest", OrderCol.DESCENDING));
        }
        super.doListBefore(query,model,context);
    }

    @Override
    protected int viewAfter(Long id, Map<String, Object> model, SiteMatterAssistEntity entity, Context context) throws AppException {
        this.service.addViewsCount(id);
        return 1;
    }

    /**
     * 推荐/取消推荐
     * @param id
     * @return
     */
    @GetMapping(value = "suggest")
    public String suggest(@RequestParam(value = "id") Long id) {
        Map<String, Object> model = new HashMap();
        if (id == null) {
            return this.createFailJsonResp("请选择待操作的数据");
        } else {
            JSONObject ret = new JSONObject();
            String busiDesc = "推荐/取消推荐" + this.getModuleDesc();
            Context context = this.getContext();
            try {
                SiteMatterAssistEntity entity = this.service.get(id, context);
                if (entity == null) {
                    throw new Exception(busiDesc + "，不存在或已被删除");
                }

                model.putAll(model);
                model.put("entity", entity);
                if (!ObjectUtils.isEmpty(context) && !ObjectUtils.isEmpty(context.getUser())) {
                    this.recordSysLog(this.request, busiDesc + " 【成功】");
                }
                if(entity.getSuggest()==0){
                    entity.setSuggest(1);
                }else {
                    entity.setSuggest(0);
                }
                this.service.update(entity,context);
            }catch (Exception var8) {
                this.doException(this.request, busiDesc, model, var8);
                Object msg = model.get("message_info");
                return this.createFailJsonResp(msg == null ? "系统异常" : msg.toString());
            }
            this.init(model, context);
            ret.put("data", model);
            ret.put("code", 1);
            ret.put("msg", model.remove("message_info"));
            return ret.toJSONString();
        }
    }
}