package com.mortals.xhx.base.system.param.web;


import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.annotation.RepeatSubmit;
import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.common.code.PageDisplayType;
import com.mortals.framework.model.Context;

import com.mortals.framework.util.FileUtil;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.common.pdu.BannerPdu;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.*;

import com.mortals.framework.web.BaseCRUDJsonMappingController;
import com.mortals.xhx.base.system.param.model.ParamEntity;
import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.common.code.DataSatusEnum;
import com.mortals.xhx.common.code.ModStatusEnum;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.*;

import static com.mortals.xhx.common.key.ParamKey.SYS_PARAM_BANNER;

/**
 * 参数信息
 *
 * @author: zxfei
 * @date: 2022/5/7 15:38
 */
@RestController
@RequestMapping("param")
public class ParamController extends BaseCRUDJsonBodyMappingController<ParamService, ParamEntity, Long> {

    public ParamController() {
        super.setFormClass(ParamForm.class);
        super.setModuleDesc("参数信息");
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        Map<String, Object> status = new HashMap<String, Object>();
        status.put("validStatus", DataSatusEnum.getEnumMap(DataSatusEnum.CLOSE.getValue(),
                DataSatusEnum.DELETE.getValue(), DataSatusEnum.OVERDUE.getValue(), DataSatusEnum.USEOUT.getValue()));
        status.put("modStatus", ModStatusEnum.getEnumMap());
        status.put("displayType", getPageDisplayType());
        model.put(KEY_RESULT_DICT, status);
    }

    private Map<String, Object> getPageDisplayType() {
        PageDisplayType[] pageDisplayTypes = PageDisplayType.values();
        Map<String, Object> result = new HashMap<>(pageDisplayTypes.length);
        for (PageDisplayType pageDisplayType : pageDisplayTypes) {
            result.put(pageDisplayType.getValue() + "", pageDisplayType.getDesc());
        }
        return result;
    }

    @GetMapping("banner/info")
    @UnAuth
    public String getBannerInfo() {
        JSONObject jsonObject = new JSONObject();
        String busiDesc = "获取banner配置";
        try {
            String value = this.service.getValueByKey(SYS_PARAM_BANNER);
            if (ObjectUtils.isEmpty(value)) {
                BannerPdu pdu = new BannerPdu();
                jsonObject.put(KEY_RESULT_DATA, pdu);
            }else {
                BannerPdu pdu = JSONObject.parseObject(value,BannerPdu.class);
                jsonObject.put(KEY_RESULT_DATA, pdu);
            }
            recordSysLog(request, busiDesc + " 【成功】");
            jsonObject.put(KEY_RESULT_CODE, VALUE_RESULT_SUCCESS);
            jsonObject.put(KEY_RESULT_MSG, busiDesc + "成功！");
        } catch (Exception e) {
            log.error("获取异常", e);
            jsonObject.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            jsonObject.put(KEY_RESULT_MSG, super.convertException(e));
        }
        return jsonObject.toJSONString();
    }

    @PostMapping("banner/save")
    @UnAuth
    public String saveBannerInfo(@RequestBody BannerPdu pdu) {
        JSONObject jsonObject = new JSONObject();
        String busiDesc = "修改banner配置";
        try {
            ParamEntity entity = new ParamEntity();
            entity.setParamKey(SYS_PARAM_BANNER);
            entity.setParamValue(JSONObject.toJSONString(pdu));
            Long id = this.service.getIdByKey(SYS_PARAM_BANNER);
            if(id==null){
                entity.setCreateTime(new Date());
                this.service.save(entity);
            }else {
                entity.setId(id);
                entity.setUpdateTime(new Date());
                this.service.update(entity);
            }
            recordSysLog(request, busiDesc + " 【成功】");
            jsonObject.put(KEY_RESULT_CODE, VALUE_RESULT_SUCCESS);
            jsonObject.put(KEY_RESULT_MSG, busiDesc + "成功！");
        } catch (Exception e) {
            log.error("获取异常", e);
            jsonObject.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            jsonObject.put(KEY_RESULT_MSG, super.convertException(e));
        }
        return jsonObject.toJSONString();
    }

    public static void main(String[] args) {
        FileUtil.delete("E:\\pic\\1.png");
    }

}