package com.mortals.xhx.busiz.web;

import cn.hutool.core.codec.Base64;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.NumberUtil;
import cn.hutool.core.util.RandomUtil;
import cn.hutool.core.util.URLUtil;
import cn.hutool.crypto.digest.DigestAlgorithm;
import cn.hutool.crypto.digest.Digester;
import cn.hutool.http.HttpUtil;
import cn.hutool.http.Method;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.common.Rest;
import com.mortals.xhx.busiz.req.MidReq;
import com.mortals.xhx.busiz.rsp.SignResp;
import com.mortals.xhx.common.utils.EncryptionUtils;
import com.mortals.xhx.module.dept.model.DeptEntity;
import com.mortals.xhx.module.dept.model.DeptQuery;
import com.mortals.xhx.module.dept.service.DeptService;
import com.mortals.xhx.module.matter.model.MatterEntity;
import com.mortals.xhx.module.matter.model.MatterQuery;
import com.mortals.xhx.module.matter.service.MatterService;
import com.mortals.xhx.module.site.model.SiteMatterEntity;
import com.mortals.xhx.module.site.model.SiteMatterQuery;
import com.mortals.xhx.module.site.service.SiteMatterService;
import com.mortals.xhx.module.window.model.WindowEntity;
import com.mortals.xhx.module.window.model.WindowMatterEntity;
import com.mortals.xhx.module.window.model.WindowMatterQuery;
import com.mortals.xhx.module.window.model.WindowQuery;
import com.mortals.xhx.module.window.service.WindowMatterService;
import com.mortals.xhx.module.window.service.WindowService;
import lombok.extern.slf4j.Slf4j;
import org.apache.http.HttpResponse;
import org.apache.http.client.CookieStore;
import org.apache.http.client.HttpClient;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.impl.client.BasicCookieStore;
import org.apache.http.impl.client.HttpClientBuilder;
import org.apache.http.util.EntityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpMethod;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.*;
import java.util.stream.Collectors;

/**
 * 微中台签名接口
 *
 * @author:
 * @date: 2023/3/2 18:07
 */
@RestController
@RequestMapping("mid")
@Slf4j
public class MidSignApiController {

    @Value("${mid.midUrl:http://172.15.28.117:9000}")
    private String midUrl;

    @Value("${mid.appId:01C67D56D0630517}")
    private String appId;

    @Value("${mid.appKey:a0b946c858aa8d06}")
    private String appKey;

    @Value("${mid.secretKey:ad80c59e575a78ab}")
    private String secretKey;

    @PostMapping(value = "sign")
    @UnAuth
    public Rest<SignResp> midSign(@RequestBody MidReq midReq) {
        SignResp signResp = new SignResp();
        try {
            Map<String, String> headerMap = new HashMap<>();

            if("post".equalsIgnoreCase(midReq.getMethod())){
                headerMap.put("appId", appId);
                headerMap.put("appKey", appKey);
                JSONObject object1 = JSONObject.parseObject(midReq.getBody());
                headerMap.put("body", object1.toJSONString());
                String timeStamp = System.currentTimeMillis() + "";
                headerMap.put("timeStamp", timeStamp);
                String nonce = RandomUtil.randomNumbers(6);
                headerMap.put("nonce", nonce);
                headerMap.put("secretKey", secretKey);

                signResp.setAppId(appId);
                signResp.setAppKey(appKey);
                signResp.setTimeStamp(timeStamp);
                signResp.setNonce(nonce);
                signResp.setSecretKey(secretKey);
            }else if("get".equalsIgnoreCase(midReq.getMethod())){
                HashMap<String, String> paramsMap = JSON.parseObject(midReq.getBody(), HashMap.class);
                if (!paramsMap.isEmpty()) {
                    for (Map.Entry<String, String> entry : paramsMap.entrySet()) {
                        headerMap.put(entry.getKey(), entry.getValue());
                    }
                }
            }

            StringBuilder signSb = new StringBuilder();

            signSb.append("appId").append("=").append(headerMap.get("appId")).append("&");
            signSb.append("appKey").append("=").append(headerMap.get("appKey")).append("&");
            signSb.append("body").append("=").append(headerMap.get("body")).append("&");
            signSb.append("nonce").append("=").append(headerMap.get("nonce")).append("&");
            signSb.append("secretKey").append("=").append(headerMap.get("secretKey")).append("&");
            signSb.append("timeStamp").append("=").append(headerMap.get("timeStamp")).append("&");
/*            for (Map.Entry<String, String> params : headerMap.entrySet()) {
                signSb.append(params.getKey()).append("=").append(params.getValue() + "").append("&");
            }*/
            String signStr = signSb.substring(0, signSb.length() - 1);
            log.info("签名源字符串: " + signStr);
            String sign = EncryptionUtils.SHA256(signStr);
            log.info("签名计算结果: " + sign);
            signResp.setSign(sign);
            return Rest.ok(signResp);
        } catch (Exception e) {
            log.error("签名异常",e);
            return Rest.fail("签名异常！");
        }
    }

    /**
     * 透传请求
     * @param midReq
     * @return
     */
    @PostMapping(value = "trans")
    @UnAuth
    public Rest<String> trans(@RequestBody MidReq midReq) {
        try {
            Map<String, String> headerMap = new HashMap<>();
            StringBuilder signSb = new StringBuilder();
            headerMap.put("appId", appId);
            headerMap.put("appKey", appKey);
            String timeStamp = System.currentTimeMillis() + "";
            headerMap.put("timeStamp", timeStamp);
            String nonce = RandomUtil.randomNumbers(6);
            headerMap.put("nonce", nonce);
            headerMap.put("secretKey", secretKey);
            if("post".equalsIgnoreCase(midReq.getMethod())){
                JSONObject object1 = JSONObject.parseObject(midReq.getBody());
                headerMap.put("body", object1.toJSONString());
            }else if("get".equalsIgnoreCase(midReq.getMethod())){
           /*     HashMap<String, String> paramsMap = JSON.parseObject(midReq.getBody(), HashMap.class);
                if (!paramsMap.isEmpty()) {
                    for (Map.Entry<String, String> entry : paramsMap.entrySet()) {
                        headerMap.put(entry.getKey(), entry.getValue());
                    }
                }*/
            }

            signSb.append("appId").append("=").append(headerMap.get("appId")).append("&");
            signSb.append("appKey").append("=").append(headerMap.get("appKey")).append("&");
            signSb.append("body").append("=").append(headerMap.get("body")).append("&");
            signSb.append("nonce").append("=").append(headerMap.get("nonce")).append("&");
            signSb.append("secretKey").append("=").append(headerMap.get("secretKey")).append("&");
            signSb.append("timeStamp").append("=").append(headerMap.get("timeStamp")).append("&");
            String signStr = signSb.substring(0, signSb.length() - 1);
            log.info("签名源字符串: " + signStr);
            String sign = EncryptionUtils.SHA256(signStr);
            log.info("签名计算结果: " + sign);

            headerMap.put("sign", sign);
            //请求转发
            String fullUrl = URLUtil.completeUrl(midUrl, midReq.getPath());
            String body = HttpUtil.createRequest(Method.POST, fullUrl).headerMap(headerMap, true).body(headerMap.get("body")).execute().body();
            return Rest.ok(body);
        } catch (Exception e) {
            log.error("透传请求异常",e);
            return Rest.fail("透传请求异常！");
        }
    }


    private static String getSortedParams(String methodName, Map<String, String> headerMap, Map<String, String> paramsMap, String body) {
        TreeMap<String, String> paramMap = new TreeMap<>();

        // 获取query参数
        if (!paramsMap.isEmpty()) {
            for (Map.Entry<String, String> entry : paramsMap.entrySet()) {
                paramMap.put(entry.getKey(), entry.getValue());
            }
        }

        paramMap.put("appId", headerMap.get("appId"));
        paramMap.put("appKey", headerMap.get("appKey"));
        // 获取body内容
        if (HttpMethod.POST.name().equals(methodName)) {
            paramMap.put("body", body);
        }
        paramMap.put("nonce", headerMap.get("nonce"));
        paramMap.put("secretKey", headerMap.get("appSecret"));
        paramMap.put("timeStamp", headerMap.get("timeStamp"));

        StringBuilder signSb = new StringBuilder();
        for (Map.Entry<String, String> params : paramMap.entrySet()) {
            signSb.append(params.getKey()).append("=").append(params.getValue()+"").append("&");
        }
        String signStr = signSb.substring(0, signSb.length() - 1);
        System.out.println("SignDemo.签名源字符串: "+signStr);
        String sign = EncryptionUtils.SHA256(signStr);
        System.out.println("SignDemo.签名计算结果: "+sign);

        return sign;
    }
    public static void main(String[] args){
        String methodName = "POST";
        Map<String, String> headerMap = new HashMap<>();
        headerMap.put("appId", "01C67D56D0630517");
        headerMap.put("appKey", "a0b946c858aa8d06");
        headerMap.put("timeStamp", "1677922190445");
        headerMap.put("nonce", "446096");
        headerMap.put("appSecret", "ad80c59e575a78ab");

        Map<String, String> paramsMap = new HashMap<>();
        //paramsMap.put("param","哈哈哈");

        JSONObject object = new JSONObject();
        object.put("resourceId","1395585204949856264");

        JSONObject param = new JSONObject();
        param.put("aab301","510199");
        param.put("aab001","000011");
        param.put("aab004","中国人民解放军第五七0一工厂");
        param.put("aae043","2022年4月至6月");
        object.put("param",param);
        String body = object.toJSONString();
        System.out.println("body: "+body);
        //body = "{\"aab301\":\"510199\",\"aab001\":\"000011\",\"aab004\":\"中国人民解放军第五七0一工厂\",\"aae043\":\"2022年4月至6月\"}";
        JSONObject object1 = JSONObject.parseObject(body);

        System.out.println("body: "+object1.toJSONString());
        getSortedParams(methodName, headerMap, paramsMap, body);
    }
}
