package com.mortals.xhx.module.matter.service.impl;

import cn.hutool.core.util.PageUtil;
import cn.hutool.core.util.ReflectUtil;
import cn.hutool.setting.Setting;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.common.Rest;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.model.PageInfo;
import com.mortals.framework.model.Result;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.framework.util.DataUtil;
import com.mortals.xhx.base.framework.config.InterceptorConfig;
import com.mortals.xhx.common.code.FiletypeEnum;
import com.mortals.xhx.common.code.SourceEnum;
import com.mortals.xhx.common.code.YesNoEnum;
import com.mortals.xhx.common.utils.BeanUtil;
import com.mortals.xhx.common.utils.MatterDetailHtmlParseUtil;
import com.mortals.xhx.module.dept.model.DeptEntity;
import com.mortals.xhx.module.dept.service.DeptService;
import com.mortals.xhx.module.matter.dao.MatterDao;
import com.mortals.xhx.module.matter.model.*;
import com.mortals.xhx.module.matter.model.vo.MatterInfo;
import com.mortals.xhx.module.matter.service.*;
import com.mortals.xhx.module.matters.model.MattersDetailEntity;
import com.mortals.xhx.module.matters.model.MattersDetailQuery;
import com.mortals.xhx.module.matters.model.MattersEntity;
import com.mortals.xhx.module.matters.model.MattersQuery;
import com.mortals.xhx.module.matters.service.MattersDetailService;
import com.mortals.xhx.module.matters.service.MattersService;
import com.mortals.xhx.module.site.model.*;
import com.mortals.xhx.module.site.service.SiteMatterService;
import com.mortals.xhx.module.site.service.SiteService;
import lombok.extern.slf4j.Slf4j;
import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.ObjectUtils;

import java.util.*;
import java.util.stream.Collectors;

/**
 * MatterService
 * 基础事项 service实现
 *
 * @author zxfei
 * @date 2022-01-12
 */
@Service("matterService")
@Slf4j
public class MatterServiceImpl extends AbstractCRUDServiceImpl<MatterDao, MatterEntity, Long> implements MatterService {
    @Autowired
    private SiteMatterService siteMatterService;
    @Autowired
    private SiteService siteService;
    @Autowired
    private MattersService mattersService;
    @Autowired
    private InterceptorConfig interceptorConfig;
    @Autowired
    private MattersDetailService mattersDetailService;
    @Autowired
    private MatterFlowlimitService matterFlowlimitService;
    @Autowired
    private MatterAcceptService matterAcceptService;
    @Autowired
    private MatterSetbaseService matterSetbaseService;
    @Autowired
    private MatterQuestionService matterQuestionService;
    @Autowired
    private MatterIntermediaryService matterIntermediaryService;
    @Autowired
    private MatterDatumService matterDatumService;
    @Autowired
    private MatterDatumFileService matterDatumFileService;
    @Autowired
    private MatterChargesService matterChargesService;
    @Autowired
    private DeptService deptService;
    @Autowired
    private MatterExtService matterExtService;
//    @Autowired
//    private SiteThemeMatterService siteThemeMatterService;
//    @Autowired
//    private SiteThemeService siteThemeService;
//    @Autowired
//    private WindowMatterService windowMatterService;


    @Override
    protected void saveBefore(MatterEntity entity, Context context) throws AppException {
        //判断如果是自定义事项，需要更新区域编码
        if (SourceEnum.自定义.getValue().equals(entity.getSource())) {
            if (!ObjectUtils.isEmpty(entity.getSiteId())) {
                SiteEntity siteEntity = siteService.get(entity.getSiteId(), context);
                entity.setAreaCode(siteEntity.getAreaCode());
                DeptEntity extCache = deptService.getExtCache(entity.getDeptCode());
                entity.setDeptName(extCache == null ? "" : extCache.getName());
            }

        }
        super.saveBefore(entity, context);
    }

    /**
     * @param entity
     * @param context
     * @throws AppException
     */
    @Override
    protected void saveAfter(MatterEntity entity, Context context) throws AppException {
        //主题添加自定义关联
//        if (!ObjectUtils.isEmpty(entity.getThemeCode())) {
//            SiteThemeEntity siteThemeEntity = siteThemeService.selectOne(new SiteThemeQuery().siteId(entity.getSiteId()).themeCode(entity.getThemeCode()));
//            SiteThemeMatterEntity siteThemeMatterEntity = new SiteThemeMatterEntity();
//            siteThemeMatterEntity.initAttrValue();
//            siteThemeMatterEntity.setThemeCode(entity.getThemeCode());
//            siteThemeMatterEntity.setSiteId(entity.getSiteId());
//            siteThemeMatterEntity.setSource(entity.getSource());
//            siteThemeMatterEntity.setMatterId(entity.getId());
//            siteThemeMatterEntity.setMatterCode(entity.getMatterNo());
//            siteThemeMatterEntity.setMatterName(entity.getMatterName());
//            siteThemeMatterEntity.setUserType(siteThemeEntity == null ? "2" : siteThemeEntity.getUserType());
//            siteThemeMatterEntity.setCreateTime(new Date());
//            siteThemeMatterEntity.setCreateUserId(this.getContextUserId(context));
//            siteThemeMatterService.save(siteThemeMatterEntity, context);
//        }

        super.saveAfter(entity, context);
    }

    @Override
    protected void updateBefore(MatterEntity entity, Context context) throws AppException {
        if (SourceEnum.自定义.getValue().equals(entity.getSource())) {
            if (!ObjectUtils.isEmpty(entity.getSiteId())) {
                SiteEntity siteEntity = siteService.get(entity.getSiteId(), context);
                entity.setAreaCode(siteEntity.getAreaCode());
                DeptEntity extCache = deptService.getExtCache(entity.getDeptCode());
                entity.setDeptName(extCache == null ? "" : extCache.getName());
            }
            MatterEntity beforeMatterEntity = this.get(entity.getId(), context);
            //如果部门切换了 级联修改关联的其它项
            if (!ObjectUtils.isEmpty(entity.getDeptCode())) {
                if (!entity.getDeptCode().equals(beforeMatterEntity.getDeptCode())) {
                    //更新站点事项关联项
                    SiteMatterQuery condition = new SiteMatterQuery();
                    condition.setMatterId(entity.getId());
                    SiteMatterQuery siteMatterQuery = new SiteMatterQuery();
                    DeptEntity extCache = deptService.getExtCache(entity.getDeptCode());

                    siteMatterQuery.setDeptId(extCache == null ? 0L : extCache.getId());
                    siteMatterQuery.setDeptCode(entity.getDeptCode());
                    siteMatterQuery.setDeptName(entity.getDeptName());
                    siteMatterService.updateBatch(siteMatterQuery, condition, context);

                    //更新站点窗口事项关联项
//                    WindowMatterQuery winCondition = new WindowMatterQuery();
//                    winCondition.setSiteMatterId(entity.getId());
//                    WindowMatterQuery windowMatterQuery = new WindowMatterQuery();
//                    windowMatterQuery.setDeptId(extCache == null ? 0L : extCache.getId());
//                    windowMatterQuery.setDeptCode(entity.getDeptCode());
//                    windowMatterQuery.setDeptName(entity.getDeptName());
//                    windowMatterService.updateBatch(windowMatterQuery, winCondition, context);
                }
            }

        }
        super.updateBefore(entity, context);
    }


    @Override
    protected void updateAfter(MatterEntity entity, Context context) throws AppException {
        //同步更新所有站点
        List<SiteMatterEntity> collect = siteMatterService.find(new SiteMatterQuery().matterId(entity.getId())).stream()
                .map(item -> {
                    item.setMatterName(entity.getMatterName());
                    return item;
                }).collect(Collectors.toList());
        siteMatterService.update(collect, context);
        super.updateAfter(entity, context);
    }


    @Override
    protected void removeBefore(Long[] ids, Context context) throws AppException {
        //有子节点 禁止删除
        super.removeBefore(ids, context);
    }

    @Override
    public Rest<String> addMatterToSite(String matterIds, Long siteId, Context context) {
        if (ObjectUtils.isEmpty(siteId)) {
            throw new AppException("请选择对应站点");
        }
        List<Long> matterIdList = Arrays.asList(matterIds.split(",")).stream().map(Long::parseLong).collect(Collectors.toList());
        MatterQuery matterQuery = new MatterQuery();
        matterQuery.setIdList(matterIdList);
        List<MatterEntity> matterEntities = this.find(matterQuery);
        int success = 0;
        int fail = 0;
        List<SiteMatterEntity> siteMatterEntities = new ArrayList<>();

        for (MatterEntity matterEntity : matterEntities) {
            SiteMatterEntity siteMatterEntity = updateOrSave(matterEntity, siteId, context);
            if (!ObjectUtils.isEmpty(siteMatterEntity)) {
                siteMatterEntities.add(siteMatterEntity);
                success++;
            } else {
                fail++;
            }
        }
        if (!ObjectUtils.isEmpty(siteMatterEntities)) {
            siteMatterService.save(siteMatterEntities, context);
        }
        String msg = "当前加入事项已存在！";
        if (matterIdList.size() == 1) {
            if (success > 0) {
                msg = "加入事项成功！";
            }
        } else if (matterIdList.size() > 1) {
            if (success > 0 && fail == 0) {
                msg = String.format("加入事项成功%d条!", success);
            } else if (success > 0 && fail > 0) {
                msg = String.format("加入事项成功%d条，重复加入事项%d条！", success, fail);
            } else if (success == 0 && fail > 0) {
                msg = String.format("重复加入事项%d条！", fail);
            }
        }
        return Rest.ok(msg);
    }

    private SiteMatterEntity updateOrSave(MatterEntity item, Long siteId, Context context) {
        SiteMatterEntity siteMatterEntity = siteMatterService.selectOne(new SiteMatterQuery().siteId(siteId).matterId(item.getId()));
        if (ObjectUtils.isEmpty(siteMatterEntity)) {
            SiteEntity siteEntity = siteService.getCache(siteId.toString());
            Rest<SiteMatterEntity> rest = switchMatterToSiteMatter(item, siteEntity, context);
            if (rest.getCode() == YesNoEnum.YES.getValue()) {
                return rest.getData();
            }
        }
        return null;
    }

    @Override
    public Rest<SiteMatterEntity> switchMatterToSiteMatter(MatterEntity item, SiteEntity siteEntity, Context context) {
        try {
            DeptEntity deptEntity = deptService.getExtCache(item.getDeptCode());
            SiteMatterEntity siteMatterEntity = new SiteMatterEntity();
            //SiteEntity siteEntity = siteService.get(siteId);
            siteMatterEntity.setSiteId(siteEntity.getId());
            siteMatterEntity.setSiteName(siteEntity.getSiteName());
            siteMatterEntity.setMatterId(item.getId());
            siteMatterEntity.setMatterCode(item.getMatterNo());
            siteMatterEntity.setMatterName(item.getMatterName());
            siteMatterEntity.setMatterCode(item.getTcode());
            siteMatterEntity.setDeptCode(item.getDeptCode());
            siteMatterEntity.setSource(item.getSource());
            siteMatterEntity.setEventTypeShow(item.getEventTypeShow());
            siteMatterEntity.setViewsCount(0l);
            siteMatterEntity.setIsConvert(0);
            siteMatterEntity.setUrl(item.getUrl());
            siteMatterEntity.setDeptName(deptEntity == null ? "" : deptEntity.getName());
            siteMatterEntity.setDeptId(deptEntity == null ? -1L : deptEntity.getId());
            siteMatterEntity.setCreateUserId(context == null ? 1L : context.getUser() == null ? 1L : context.getUser().getId());
            siteMatterEntity.setCreateTime(new Date());
            return Rest.ok(siteMatterEntity);

        } catch (Exception e) {
            log.error("转换异常", e);
            return Rest.fail(e.getMessage());
        }
    }

    @Override
    public Result<MatterEntity> findSubList(MatterEntity matterQuery, PageInfo pageInfo, Context context) throws AppException {
        SiteEntity siteCache = siteService.getCache(matterQuery.getSiteId().toString());
        if (ObjectUtils.isEmpty(matterQuery.getAreaCode())) {
            matterQuery.setAreaCode(siteCache == null ? null : siteCache.getAreaCode());
        }
        return this.dao.getSubList(matterQuery, pageInfo);
    }

    @Override
    public Result<MatterInfo> findMicroList(MatterQuery matterQuery, PageInfo pageInfo, Context context) throws AppException {
        Result<MatterInfo> matterInfoResult = new Result<>();
        Result<MatterEntity> matterEntityResult = this.find(matterQuery, pageInfo, context);
        List<MatterInfo> matterInfoList = matterEntityResult.getList().stream().map(item -> {
            MatterInfo matterInfo = new MatterInfo();
            BeanUtils.copyProperties(item, matterInfo, BeanUtil.getNullPropertyNames(item));
            return matterInfo;
        }).collect(Collectors.toList());
        matterInfoResult.setList(matterInfoList);
        matterInfoResult.setPageInfo(pageInfo);

        return matterInfoResult;
    }


    @Override
    public void syncMatter(String areaCode, Context context) {
        List<MatterEntity> list = this.find(new MatterQuery().source(SourceEnum.政务网.getValue()));
        if (!ObjectUtils.isEmpty(list)) {
            // TODO: 2022/3/30  查询本地数据，进行交叉更新对比
            //暂时以删除后重新添加为准
            //this.getDao().delete(new MatterQuery().source(SourceEnum.政务网.getValue()));
        }
        //读取区域数据
        //mattersAreaService.find()
        //读取事项基础数据

        MattersQuery mattersQuery = new MattersQuery();
        if (!ObjectUtils.isEmpty(areaCode)) {
            //查询区域与当前区域
        }

        Integer total = mattersService.count(mattersQuery, null);
        int totalPage = PageUtil.totalPage(total, 1000);
        for (int i = 0; i < totalPage; i++) {
            PageInfo pageInfo = new PageInfo();
            pageInfo.setCurrPage(i);
            pageInfo.setPrePageResult(1000);
            List<MattersEntity> mattersEntities = mattersService.find(mattersQuery, pageInfo, null).getList();
            for (MattersEntity item : mattersEntities) {
                if ("true".equals(item.getHaveGetMatterInfo())) {
                    MattersDetailEntity itemDetail = mattersDetailService.selectOne(new MattersDetailQuery().matterCode(item.getMatterCode()));
                    if (!ObjectUtils.isEmpty(itemDetail)) {
                        //解析事项详细数据
                        MatterEntity matterEntity = new MatterEntity();
                        matterEntity.initAttrValue();
                        matterEntity.setMatterNo(item.getMatterCode());
                        matterEntity.setTcode(item.getMatterCode());
                        matterEntity.setMatterName(item.getName());
                        matterEntity.setTname(item.getName());
                        matterEntity.setSource(SourceEnum.政务网.getValue());
                        matterEntity.setCreateTime(new Date());
                        matterEntity.setCreateUserName("system");
                        matterEntity.setCreateUserId(1L);
                        String basicinfoJbxx = itemDetail.getBasicinfoJbxx();
                        //解析基础数据
                        //todo 设置基础值
                        //基本信息属性与字段映射表
                        Setting baseInfoSetting = interceptorConfig.getBaseInfoSetting();
                        Setting sqclInfoSetting = interceptorConfig.getSqclInfoSetting();
                        createBaseMatterJson(basicinfoJbxx, baseInfoSetting, matterEntity);

                        matterEntity.setAreaCode(item.getAreaCode());
                        matterEntity.setDeptCode(item.getDeptCode());
                        matterEntity.setThemeCode(item.getThemeCode());
                        matterEntity.setPowerCode(item.getPowerCode());
                        matterEntity.setGroupName(item.getGroupName());
                        matterEntity.setHaveGetMatterInfo(item.getHaveGetMatterInfo());
                        matterEntity.setUsertypeCode(item.getUsertypeCode());
                        matterEntity.setUrl(item.getUrl());
                        this.save(matterEntity);
                        //todo 材料
                        String sqclJson = itemDetail.getMaterialsSqcl();
                        if (!ObjectUtils.isEmpty(sqclJson) || !"{}".equals(sqclJson)) {
                            createSqclJson(sqclJson, sqclInfoSetting, matterEntity);
                        }
                        //todo 受理条件
                        String sltjJson = itemDetail.getConditionsSltj();
                        if (!ObjectUtils.isEmpty(sltjJson) || !"{}".equals(sltjJson)) {
                            createSltjJson(sltjJson, matterEntity);
                        }

                        //todo 收费标准
                        String sfbzJson = itemDetail.getChargingSfbz();
                        if (!ObjectUtils.isEmpty(sfbzJson) || !"{}".equals(sfbzJson)) {
                            createSfbzJson(sfbzJson, matterEntity);
                        }
                        //todo 办理流程
                        String bllcJson = itemDetail.getProcessBllc();
                        if (!ObjectUtils.isEmpty(bllcJson) || !"{}".equals(bllcJson)) {
                            createBllcJson(bllcJson, matterEntity);
                        }
                        //todo 常见问题
                        String cjwtJson = itemDetail.getQuestionCjwt();
                        if (!ObjectUtils.isEmpty(cjwtJson) || !"{}".equals(cjwtJson)) {
                            createCjwtJson(cjwtJson, matterEntity);
                        }
                        //todo 设定依据
                        String sdyjJson = itemDetail.getBasisSdyj();
                        if (!ObjectUtils.isEmpty(sdyjJson) || !"{}".equals(sdyjJson)) {
                            createSdyjJson(sdyjJson, matterEntity);
                        }
                        //todo 中介服务
                        String zjfwJson = itemDetail.getIntermediaryZjfw();
                        if (!ObjectUtils.isEmpty(zjfwJson) || !"{}".equals(zjfwJson)) {
                            createZjfwJson(zjfwJson, matterEntity);
                        }
                    }
                }
            }
            //根据事项查询事项详细等，并更新
        }

    }

    public void createBaseMatterJson(String baseJson, Setting baseInfoSetting, MatterEntity matterEntity) {
        JSONObject root = JSON.parseObject(baseJson);
        JSONArray jsonArray = root.getJSONArray("基本信息");
        if (!ObjectUtils.isEmpty(jsonArray)) {
            for (int i = 0; i < jsonArray.size(); i++) {
                JSONArray subArray = jsonArray.getJSONArray(i);
                if (!ObjectUtils.isEmpty(subArray)) {
                    for (int j = 0; j < subArray.size(); j++) {
                        subArray.getJSONObject(j).entrySet().stream()
                                .peek(m -> {
                                    String value = baseInfoSetting.getOrDefault(m.getKey(), "");
                                    if (!ObjectUtils.isEmpty(value) && !"无".equals(m.getValue())) {
                                        //value 为对象配置的属性值，反射设置属性值
                                        try {
                                            ReflectUtil.setFieldValue(matterEntity, value, m.getValue().toString().replaceAll("、", ","));
                                        } catch (Exception e) {
                                            log.error(String.format("设置值异常！key:%s,value:%s", value, m.getValue()));
                                        }
                                    }
                                }).count();
                    }
                }
            }
        }
        //反射设置事项属性
    }

    public void createSqclJson(String sqclJson, Setting sqclInfoSetting, MatterEntity matterEntity) {
        JSONObject root = null;
        try {
            root = JSON.parseObject(sqclJson);
        } catch (Exception e) {
            sqclJson = sqclJson.replaceAll("\\\\", "\\\\\\\\");
            try {
                root = JSON.parseObject(sqclJson);
            } catch (Exception e1) {
                //log.error("error json:" + sqclJson);
                return;
            }
        }

        if (root.isEmpty()) {
            //log.info("root is null");
            return;
        }
        JSONArray jsonArray = null;
        try {
            jsonArray = root.getJSONArray("申请材料");
        } catch (Exception e) {
            log.error("error 无申请材料");
        }

        if (ObjectUtils.isEmpty(jsonArray)) {
            log.info("申请材料 is null");
            return;
        }

        for (int i = 0; i < jsonArray.size(); i++) {
            JSONObject secondJsonObject = jsonArray.getJSONObject(i);
            MatterDatumEntity datumEntity = new MatterDatumEntity();
            datumEntity.initAttrValue();
            datumEntity.setMatterId(matterEntity.getId());
            datumEntity.setMaterialName(matterEntity.getMatterName());
            datumEntity.setSource(SourceEnum.政务网.getValue());
            datumEntity.setCreateTime(new Date());
            datumEntity.setCreateUser("system");
            datumEntity.setCreateUserId(1L);

            //材料详情
            JSONArray jsonArrayThree = secondJsonObject.getJSONArray("材料详情");
            if (!ObjectUtils.isEmpty(jsonArrayThree)) {
                for (int j = 0; j < jsonArrayThree.size(); j++) {
                    jsonArrayThree.getJSONObject(j).entrySet().stream().peek(m -> {
                        String value = sqclInfoSetting.getOrDefault(m.getKey(), "");
                        if (!ObjectUtils.isEmpty(value)) {
                            //value 为对象配置的属性值，反射设置属性值
                            try {
                                ReflectUtil.setFieldValue(datumEntity, value, m.getValue().toString().replaceAll("、", ","));
                            } catch (Exception e) {
                                log.error(String.format("设置值异常！key:%s,value:%s", value, m.getValue()));
                            }
                        }
                    }).count();
                }
            }
            matterDatumService.save(datumEntity);
            //示例样表
            JSONArray jsonArrayone = secondJsonObject.getJSONArray("示例样表");
            if (!ObjectUtils.isEmpty(jsonArrayone)) {
                ArrayList<MatterDatumFileEntity> fileArrayList = new ArrayList<>();
                for (int j = 0; j < jsonArrayone.size(); j++) {
                    MatterDatumFileEntity fileEntity = new MatterDatumFileEntity();
                    fileEntity.setCreateTime(new Date());
                    fileEntity.setCreateUser("system");
                    fileEntity.setCreateUserId(1L);
                    fileEntity.setDatumId(datumEntity.getId());
                    fileEntity.setMaterialName(datumEntity.getMaterialName());
                    fileEntity.setSource(SourceEnum.政务网.getValue());
                    fileEntity.setFiletype(FiletypeEnum.空白表格.getValue());
                    jsonArrayone.getJSONObject(j).entrySet().stream().peek(m -> {
                        fileEntity.setFileName(m.getKey());
                        fileEntity.setFileUrl(m.getValue().toString());
                    }).count();
                    fileArrayList.add(fileEntity);
                }
                matterDatumFileService.save(fileArrayList);

            }
            //空白表格
            JSONArray jsonArraytwo = secondJsonObject.getJSONArray("空白表格");
            if (!ObjectUtils.isEmpty(jsonArraytwo)) {
                ArrayList<MatterDatumFileEntity> fileArrayList = new ArrayList<>();
                for (int j = 0; j < jsonArraytwo.size(); j++) {
                    MatterDatumFileEntity fileEntity = new MatterDatumFileEntity();
                    fileEntity.setCreateTime(new Date());
                    fileEntity.setCreateUser("system");
                    fileEntity.setDatumId(datumEntity.getId());
                    fileEntity.setMaterialName(datumEntity.getMaterialName());
                    fileEntity.setSource(SourceEnum.政务网.getValue());
                    fileEntity.setFiletype(FiletypeEnum.空白表格.getValue());
                    jsonArraytwo.getJSONObject(j).entrySet().stream().peek(m -> {
                        fileEntity.setFileName(m.getKey());
                        fileEntity.setFileUrl(m.getValue().toString());
                    }).count();
                    fileArrayList.add(fileEntity);
                }
                matterDatumFileService.save(fileArrayList);
            }
        }

    }

    public void createSltjJson(String sltjJson, MatterEntity matterEntity) {
        if (ObjectUtils.isEmpty(sltjJson) || "{}".equals(sltjJson)) {
            return;
        }
        JSONObject root = null;
        try {
            root = JSON.parseObject(sltjJson);
        } catch (Exception e) {
            sltjJson = sltjJson.replaceAll("\\\\", "\\\\\\\\");
            try {
                root = JSON.parseObject(sltjJson);
            } catch (Exception e1) {
                // log.error("error json:" + sltjJson);
                return;
            }
        }

        if (root.isEmpty()) {
            //log.info("root is null");
            return;
        }

        String value = null;
        try {
            value = root.getString("受理条件");
            MatterAcceptEntity matterAcceptEntity = new MatterAcceptEntity();
            matterAcceptEntity.initAttrValue();
            matterAcceptEntity.setContent(value);
            matterAcceptEntity.setMatterId(matterEntity.getId());
            matterAcceptEntity.setMatterName(matterEntity.getMatterName());
            matterAcceptEntity.setSource(SourceEnum.政务网.getValue());
            matterAcceptEntity.setCreateTime(new Date());
            matterAcceptEntity.setCreateUser("system");
            matterAcceptEntity.setCreateUserId(1L);
            matterAcceptService.save(matterAcceptEntity);
        } catch (Exception e) {
            log.error("error 受理条件", e);
        }
    }

    public void createSfbzJson(String sfbzJson, MatterEntity matterEntity) {
        if (ObjectUtils.isEmpty(sfbzJson) || "{}".equals(sfbzJson)) {
            return;
        }
        JSONObject root = null;
        try {
            root = JSON.parseObject(sfbzJson);
        } catch (Exception e) {
            sfbzJson = sfbzJson.replaceAll("\\\\", "\\\\\\\\");
            try {
                root = JSON.parseObject(sfbzJson);
            } catch (Exception e1) {
                //log.error("error json:" + sfbzJson);
                return;
            }
        }

        if (root.isEmpty()) {
            //log.info("root is null");
            return;
        }

        String value = null;
        try {
            value = root.getString("收费标准");
            MatterChargesEntity matterChargesEntity = new MatterChargesEntity();
            matterChargesEntity.initAttrValue();
            matterChargesEntity.setContent(value);
            matterChargesEntity.setMatterId(matterEntity.getId());
            matterChargesEntity.setMatterName(matterEntity.getMatterName());
            matterChargesEntity.setSource(SourceEnum.政务网.getValue());
            matterChargesEntity.setCreateTime(new Date());
            matterChargesEntity.setCreateUser("system");
            matterChargesEntity.setCreateUserId(1L);
            matterChargesService.save(matterChargesEntity);
        } catch (Exception e) {
            log.error("error 收费标准", e);
        }
    }

    public void createCjwtJson(String cjwtJson, MatterEntity matterEntity) {
        if (ObjectUtils.isEmpty(cjwtJson) || "{}".equals(cjwtJson)) {
            //log.info("json:" + cjwtJson);
            return;
        }
        JSONObject root = null;
        try {
            root = JSON.parseObject(cjwtJson);
        } catch (Exception e) {
            cjwtJson = cjwtJson.replaceAll("\\\\", "\\\\\\\\");
            try {
                root = JSON.parseObject(cjwtJson);
            } catch (Exception e1) {
                //log.error("error json:" + cjwtJson);
                return;
            }
        }

        if (root.isEmpty()) {
            //log.info("root is null");
            return;
        }
        JSONArray jsonArray = null;
        try {
            jsonArray = root.getJSONArray("常见问题");
        } catch (Exception e) {
            //log.error("error 无常见问题");
        }

        if (ObjectUtils.isEmpty(jsonArray)) {
            //log.info("常见问题 is null");
            return;
        }

        for (int i = 0; i < jsonArray.size(); i++) {
            JSONObject jsonObject = jsonArray.getJSONObject(i);
            List<MatterQuestionEntity> questionEntityList = jsonObject.entrySet().stream().map(question -> {
                MatterQuestionEntity questionEntity = new MatterQuestionEntity();
                questionEntity.initAttrValue();
                questionEntity.setQuestion(question.getKey());
                questionEntity.setAnswer(question.getValue().toString());
                questionEntity.setMatterId(matterEntity.getId());
                questionEntity.setMatterName(matterEntity.getMatterName());
                questionEntity.setSource(SourceEnum.政务网.getValue());
                questionEntity.setCreateTime(new Date());
                questionEntity.setCreateUser("system");
                return questionEntity;
            }).collect(Collectors.toList());
            matterQuestionService.save(questionEntityList);
        }
    }

    public void createBllcJson(String bllcJson, MatterEntity matterEntity) {
        if (ObjectUtils.isEmpty(bllcJson) || "{}".equals(bllcJson)) {
            //log.info("json:" + cjwtJson);
            return;
        }
        JSONObject root = null;
        try {
            root = JSON.parseObject(bllcJson);
        } catch (Exception e) {
            bllcJson = bllcJson.replaceAll("\\\\", "\\\\\\\\");
            try {
                root = JSON.parseObject(bllcJson);
            } catch (Exception e1) {
                log.error("error json:" + bllcJson);
                return;
            }
        }

        if (root == null || root.isEmpty()) {
            //log.info("root is null");
            return;
        }
        JSONArray jsonArray = null;
        try {
            jsonArray = root.getJSONArray("办理流程");
        } catch (Exception e) {
            log.error("error 无办理流程");
        }

        if (ObjectUtils.isEmpty(jsonArray)) {
            //log.info("办理流程 is null");
            return;
        }

        List<MatterFlowlimitEntity> flowlimitEntityArrayList = new ArrayList<>();

        for (int i = 0; i < jsonArray.size(); i++) {
            MatterFlowlimitEntity matterFlowlimitEntity = new MatterFlowlimitEntity();
            matterFlowlimitEntity.initAttrValue();
            matterFlowlimitEntity.setMatterId(matterEntity.getId());
            matterFlowlimitEntity.setMatterName(matterEntity.getMatterName());
            matterFlowlimitEntity.setSource(SourceEnum.政务网.getValue());
            matterFlowlimitEntity.setCreateTime(new Date());
            matterFlowlimitEntity.setCreateUser("system");
            matterFlowlimitEntity.setCreateUserId(1L);
            JSONArray innerJsonArray = jsonArray.getJSONArray(i);
            for (int j = 0; j < innerJsonArray.size(); j++) {
                innerJsonArray.getJSONObject(j).entrySet().stream().peek(m -> {
                    Boolean bool = false;
                    if ("办理流程".equals(m.getKey().trim())) {
                        matterFlowlimitEntity.setFlowName(m.getValue().toString());
                        bool = true;
                    }

                    if ("办理时长".equals(m.getKey().trim())) {
                        matterFlowlimitEntity.setFlowTime(m.getValue().toString());
                        bool = true;
                    }

                    if ("转外时限".equals(m.getKey().trim())) {
                        matterFlowlimitEntity.setFlowLimit(m.getValue().toString());
                        bool = true;
                    }

                    if ("办理流程说明".equals(m.getKey().trim())) {
                        matterFlowlimitEntity.setFlowDesc(m.getValue().toString());
                        bool = true;
                    }
//                    if(!bool){
//                        System.out.println("name:" + m.getKey());
//                        System.out.print(" value:" + m.getValue());
//                    }
                }).count();
            }
            flowlimitEntityArrayList.add(matterFlowlimitEntity);
        }
        matterFlowlimitService.save(flowlimitEntityArrayList);

    }

    public void createSdyjJson(String sdyjJson, MatterEntity matterEntity) {
        if (ObjectUtils.isEmpty(sdyjJson) || "{}".equals(sdyjJson)) {
            //log.info("json:" + cjwtJson);
            return;
        }
        JSONObject root = null;
        try {
            root = JSON.parseObject(sdyjJson);
        } catch (Exception e) {
            sdyjJson = sdyjJson.replaceAll("\\\\", "\\\\\\\\");
            try {
                root = JSON.parseObject(sdyjJson);
            } catch (Exception e1) {
                log.error("error json:" + sdyjJson);
                return;
            }
        }

        if (root.isEmpty()) {
            log.info("root is null");
            return;
        }
        JSONArray jsonArray = null;
        try {
            jsonArray = root.getJSONArray("设定依据");
        } catch (Exception e) {
            log.error("error 无设定依据");
        }

        if (ObjectUtils.isEmpty(jsonArray)) {
            //log.info("设定依据 is null");
            return;
        }

        List<MatterSetbaseEntity> setbaseEntityArrayList = new ArrayList<>();
        for (int i = 0; i < jsonArray.size(); i++) {
            MatterSetbaseEntity matterSetbaseEntity = new MatterSetbaseEntity();
            matterSetbaseEntity.setMatterId(matterEntity.getId());
            matterSetbaseEntity.setMatterName(matterEntity.getMatterName());
            matterSetbaseEntity.setSource(SourceEnum.政务网.getValue());
            matterSetbaseEntity.setCreateTime(new Date());
            matterSetbaseEntity.setCreateUser("system");
            matterSetbaseEntity.setCreateUserId(1L);
            JSONArray innerJsonArray = jsonArray.getJSONArray(i);
            for (int j = 0; j < innerJsonArray.size(); j++) {
                innerJsonArray.getJSONObject(j).entrySet().stream().peek(m -> {
                    if ("法律法规名称".equals(m.getKey().trim())) {
                        matterSetbaseEntity.setPolicyName(m.getValue().toString());
                    }
                    if ("法规类型".equals(m.getKey().trim())) {
                        matterSetbaseEntity.setPolicyType(m.getValue().toString());
                    }

                    if ("条例".equals(m.getKey().trim())) {
                        matterSetbaseEntity.setPolicyitem(m.getValue().toString());
                    }

                    if ("条款内容".equals(m.getKey().trim())) {
                        matterSetbaseEntity.setContent(m.getValue().toString());
                    }

                }).count();
            }
            setbaseEntityArrayList.add(matterSetbaseEntity);
        }
        matterSetbaseService.save(setbaseEntityArrayList);

    }

    public void createZjfwJson(String zjfwJson, MatterEntity matterEntity) {
        if (ObjectUtils.isEmpty(zjfwJson) || "{}".equals(zjfwJson)) {
            return;
        }
        JSONObject root = null;
        try {
            root = JSON.parseObject(zjfwJson);
        } catch (Exception e) {
            zjfwJson = zjfwJson.replaceAll("\\\\", "\\\\\\\\");
            try {
                root = JSON.parseObject(zjfwJson);
            } catch (Exception e1) {
                log.error("error json:" + zjfwJson);
                return;
            }
        }

        if (root.isEmpty()) {
            log.info("root is null");
            return;
        }
        JSONArray jsonArray = null;
        try {
            jsonArray = root.getJSONArray("中介服务");
        } catch (Exception e) {
            //log.error("error 中介服务:"+zjfwJson);
        }

        if (ObjectUtils.isEmpty(jsonArray)) {
            // log.info("中介服务 is null");
            return;
        }
        List<MatterIntermediaryEntity> intermediaryEntityArrayList = new ArrayList<>();
        for (int i = 0; i < jsonArray.size(); i++) {
            MatterIntermediaryEntity matterIntermediaryEntity = new MatterIntermediaryEntity();
            matterIntermediaryEntity.initAttrValue();
            matterIntermediaryEntity.setMatterId(matterEntity.getId());
            matterIntermediaryEntity.setMatterName(matterEntity.getMatterName());
            matterIntermediaryEntity.setSource(SourceEnum.政务网.getValue());
            matterIntermediaryEntity.setCreateTime(new Date());
            matterIntermediaryEntity.setCreateUser("system");
            matterIntermediaryEntity.setCreateUserId(1L);

            jsonArray.getJSONObject(i).entrySet().stream().forEach(m -> {
                matterIntermediaryEntity.setTitle(m.getKey().trim());
                matterIntermediaryEntity.setRemark(m.getValue().toString());

                if ("中介服务实施机构及资质资格要求".equals(m.getKey().trim())) {
                    matterIntermediaryEntity.setIntermediaryRequest(m.getValue().toString());
                }

                if ("服务时限".equals(m.getKey().trim())) {
                    matterIntermediaryEntity.setIntermediaryRequestTime(m.getValue().toString());
                }
              /*  if ("中介服务事项名称".equals(m.getKey().trim())) {
                    matterIntermediaryEntity.setTitle(m.getValue().toString());
                }
              */
            });
            intermediaryEntityArrayList.add(matterIntermediaryEntity);
        }
        matterIntermediaryService.save(intermediaryEntityArrayList);
    }

    @Override
    public Map<String, String> getBaseInfoMap(Context context) {
        Map<String, String> baseInfoMap = new HashMap<>();
        List<MattersDetailEntity> mattersDetailEntities = mattersDetailService.find(new MattersDetailQuery());
        for (MattersDetailEntity itemDetail : mattersDetailEntities) {
            buildBaseJson(itemDetail.getBasicinfoJbxx(), baseInfoMap);
        }
        return baseInfoMap;
    }

    @Override
    public Map<String, String> getSqclInfoMap(Context context) {
        Map<String, String> sqclInfoMap = new HashMap<>();
        List<MattersDetailEntity> mattersDetailEntities = mattersDetailService.find(new MattersDetailQuery());
        for (MattersDetailEntity itemDetail : mattersDetailEntities) {
            buildSqclJson(itemDetail.getMaterialsSqcl(), sqclInfoMap);
        }
        return sqclInfoMap;
    }


    public void buildBaseJson(String json, Map<String, String> model) {
        //将基本信息转成map集合返回
        JSONObject root = JSON.parseObject(json);
        JSONArray jsonArray = root.getJSONArray("基本信息");
        if (!ObjectUtils.isEmpty(jsonArray)) {
            for (int i = 0; i < jsonArray.size(); i++) {
                JSONArray subArray = jsonArray.getJSONArray(i);
                if (!ObjectUtils.isEmpty(subArray)) {
                    for (int j = 0; j < subArray.size(); j++) {
                        subArray.getJSONObject(j).entrySet().stream()
                                .filter(f -> f.getKey().length() < 12)
                                .filter(f -> f.getKey().indexOf("许可证") == -1)
                                .filter(f -> f.getKey().indexOf("《") == -1)
                                .filter(f -> f.getKey().indexOf("x") == -1)
                                .filter(f -> f.getKey().indexOf("X") == -1)
                                .filter(f -> f.getKey().indexOf("*") == -1)
                                .filter(f -> f.getKey().indexOf("关于") == -1)
                                .filter(f -> f.getKey().indexOf(".") == -1)
                                .filter(f -> DataUtil.converStr2Int(f.getKey(), 0) == 0)
                                .filter(f -> !"下载".equals(f.getValue().toString().trim()))
                                .filter(f -> !"查看".equals(f.getValue().toString().trim()))
                                .peek(m -> {
                                    // model.put(m.getKey(), m.getValue().toString());
                                    model.put(m.getKey(), "");
                                }).count();
                    }
                }
            }

        }
    }


    public void buildSqclJson(String sqclJson, Map<String, String> model) {
        //将基本信息转成map集合返回
        JSONObject root = null;
        try {
            root = JSON.parseObject(sqclJson);
        } catch (Exception e) {
            sqclJson = sqclJson.replaceAll("\\\\", "\\\\\\\\");
            try {
                root = JSON.parseObject(sqclJson);
            } catch (Exception e1) {
                log.error("error json:" + sqclJson);
                return;
            }
        }

        if (root.isEmpty()) {
            log.info("root is null");
            return;
        }
        JSONArray jsonArray = null;
        try {
            jsonArray = root.getJSONArray("申请材料");
        } catch (Exception e) {
            log.error("error 无申请材料");
        }

        if (ObjectUtils.isEmpty(jsonArray)) {
            //  log.info("申请材料 is null");
            return;
        }
        if (!ObjectUtils.isEmpty(jsonArray)) {
            for (int i = 0; i < jsonArray.size(); i++) {
                try {
                    JSONObject subObject = jsonArray.getJSONObject(i);
                    if (!ObjectUtils.isEmpty(subObject)) {
                        JSONArray subsArray = subObject.getJSONArray("材料详情");
                        if (!ObjectUtils.isEmpty(subsArray)) {
                            for (int j = 0; j < subsArray.size(); j++) {
                                subsArray.getJSONObject(j).entrySet().stream()
                                        .peek(m -> {
                                            if ("要求提供材料的依据".equals(m.getKey())
                                                    || "备注".equals(m.getKey())
                                                    || "来源渠道说明".equals(m.getKey())
                                                    || "材料名称".equals(m.getKey())
                                                    || "受理标准".equals(m.getKey())
                                                    || "填报须知".equals(m.getKey())
                                                    || "来源渠道".equals(m.getKey())) {
                                                model.put(m.getKey(), "");
                                            } else {
                                                if (model.containsKey(m.getKey())) {
                                                    String value = model.get(m.getKey());
                                                    Set<String> valueSet = Arrays.asList(value.split(",")).stream().collect(Collectors.toSet());
                                                    if (!valueSet.contains(m.getValue().toString())) {
                                                        valueSet.add(m.getValue().toString());
                                                    }
                                                    model.put(m.getKey(), valueSet.stream().collect(Collectors.joining(",")));
                                                } else {
                                                    model.put(m.getKey(), m.getValue().toString());
                                                }
                                            }
                                            //log.info(String.format("model:%s", JSON.toJSONString(model)));
                                            // model.put(m.getKey(), m.getValue().toString());
                                            //model.put(m.getKey(), "");
                                        }).count();
                            }
                        }
                    }
                } catch (Exception e) {
                    log.error("异常:" + sqclJson);
                }
            }

        }
    }


    @Override
    public Rest<String> buildMatterDetail(MatterEntity matterEntity, Context context) {
        //根据事项url 获取事项详细信息，构建相关详细信息
        String html = null;
        try {
            Document dom = Jsoup.connect(matterEntity.getUrl()).get();
            // html = Jsoup.connect(matterEntity.getUrl()).get().body().html();
            // html = HttpUtil.get(matterEntity.getUrl());
            //System.out.println(html);
            // log.info("build detail:" + matterEntity.getMatterNo());
            //设置基本属性值
            Setting baseInfoSetting = interceptorConfig.getBaseInfoSetting();
            Setting sqclInfoSetting = interceptorConfig.getSqclInfoSetting();

            //更新部门信息
            DeptEntity extCache = deptService.getExtCache(matterEntity.getDeptCode());
            matterEntity.setDeptName(extCache == null ? "" : extCache.getName());

/*            if(!ObjectUtils.isEmpty(matterEntity.getDeptCode())&&ObjectUtils.isEmpty(matterEntity.getDeptName())){
                DeptEntity extCache = deptService.getExtCache(matterEntity.getDeptCode());
                matterEntity.setDeptName(extCache==null?"":extCache.getName());
            }*/
            //构建基础信息参数
            savebaseInfo(matterEntity, dom, baseInfoSetting);

            //更新材料属性
            saveDatumInfo(matterEntity, context, dom, sqclInfoSetting);

            //更新受理条件
            saveSltjInfo(matterEntity, context, dom);

            //更新办理流程
            saveBllcInfo(matterEntity, context, dom);

            //更新收费标准
            saveSfbzInfo(matterEntity, context, dom);

            //设定依据
            saveSdyjInfo(matterEntity, context, dom);

            //中介服务
            saveZjfwInfo(matterEntity, context, dom);

            //常见问题
            saveCjwtInfo(matterEntity, context, dom);

            //更新事项更新标志
            matterEntity.setHaveGetMatterInfo("true");

        } catch (Exception e) {
            log.error(String.format("获取详细异常! id:%s,matterCode:%s,url:%s", matterEntity.getId(), matterEntity.getMatterNo(), matterEntity.getUrl()), e);
            return Rest.fail("更新事项失败！" + e.getMessage());
        }
        return Rest.ok("更新详细成功！");
    }


    private void saveCjwtInfo(MatterEntity matterEntity, Context context, Document dom) {
        matterQuestionService.deleteByMatterId(matterEntity.getId(), context);
        List<Map<String, Object>> cjwtMapList = MatterDetailHtmlParseUtil.getCjwtMapByHtml(dom);
        List<MatterQuestionEntity> questionEntityList = new ArrayList<>();
        for (Map<String, Object> cjwtMap : cjwtMapList) {
            List<MatterQuestionEntity> collect = cjwtMap.entrySet().stream().map(question -> {
                MatterQuestionEntity questionEntity = new MatterQuestionEntity();
                questionEntity.initAttrValue();
                questionEntity.setQuestion(question.getKey());
                questionEntity.setAnswer(question.getValue().toString());
                questionEntity.setMatterId(matterEntity.getId());
                questionEntity.setMatterCode(matterEntity.getMatterNo());
                questionEntity.setMatterName(matterEntity.getMatterName());
                questionEntity.setSource(SourceEnum.政务网.getValue());
                questionEntity.setCreateTime(new Date());
                questionEntity.setCreateUser("system");
                return questionEntity;
            }).collect(Collectors.toList());
            questionEntityList.addAll(collect);
        }
        matterQuestionService.save(questionEntityList);
    }

    private void saveZjfwInfo(MatterEntity matterEntity, Context context, Document dom) {
        matterIntermediaryService.deleteByMatterId(matterEntity.getId(), context);
        Map<String, String> zjfwMap = MatterDetailHtmlParseUtil.getZjfwMapByHtml(dom);
        List<MatterIntermediaryEntity> intermediaryEntityArrayList = new ArrayList<>();
        zjfwMap.entrySet().stream().forEach(m -> {
            MatterIntermediaryEntity matterIntermediaryEntity = new MatterIntermediaryEntity();
            matterIntermediaryEntity.initAttrValue();
            matterIntermediaryEntity.setMatterId(matterEntity.getId());
            matterIntermediaryEntity.setMatterCode(matterEntity.getMatterNo());
            matterIntermediaryEntity.setMatterName(matterEntity.getMatterName());
            matterIntermediaryEntity.setSource(SourceEnum.政务网.getValue());
            matterIntermediaryEntity.setCreateTime(new Date());
            matterIntermediaryEntity.setCreateUser("system");
            matterIntermediaryEntity.setCreateUserId(1L);
            matterIntermediaryEntity.setTitle(m.getKey().trim());
            matterIntermediaryEntity.setRemark(m.getValue());
            intermediaryEntityArrayList.add(matterIntermediaryEntity);
        });
        matterIntermediaryService.save(intermediaryEntityArrayList);
    }

    private void saveSdyjInfo(MatterEntity matterEntity, Context context, Document dom) {
        matterSetbaseService.deleteByMatterId(matterEntity.getId(), context);
        List<MatterSetbaseEntity> setbaseEntityArrayList = new ArrayList<>();
        List<Map<String, Object>> sdyjMapList = MatterDetailHtmlParseUtil.getSdyjMapByHtml(dom);
        for (Map<String, Object> sdyjMap : sdyjMapList) {
            MatterSetbaseEntity matterSetbaseEntity = new MatterSetbaseEntity();
            matterSetbaseEntity.setMatterId(matterEntity.getId());
            matterSetbaseEntity.setMatterCode(matterEntity.getMatterNo());
            matterSetbaseEntity.setMatterName(matterEntity.getMatterName());
            matterSetbaseEntity.setSource(SourceEnum.政务网.getValue());
            matterSetbaseEntity.setCreateTime(new Date());
            matterSetbaseEntity.setCreateUser("system");
            matterSetbaseEntity.setCreateUserId(1L);
            sdyjMap.entrySet().stream().forEach(m -> {
                if ("法律法规名称".equals(m.getKey().trim())) {
                    matterSetbaseEntity.setPolicyName(m.getValue().toString());
                }
                if ("法规类型".equals(m.getKey().trim())) {
                    matterSetbaseEntity.setPolicyType(m.getValue().toString());
                }

                if ("条例".equals(m.getKey().trim())) {
                    matterSetbaseEntity.setPolicyitem(m.getValue().toString());
                }

                if ("条款内容".equals(m.getKey().trim())) {
                    matterSetbaseEntity.setContent(m.getValue().toString());
                }

            });
            setbaseEntityArrayList.add(matterSetbaseEntity);
        }
        matterSetbaseService.save(setbaseEntityArrayList);
    }

    private void saveSfbzInfo(MatterEntity matterEntity, Context context, Document dom) {
        Map<String, String> sfbzMap = MatterDetailHtmlParseUtil.getSfbzMapByHtml(dom);
        matterChargesService.deleteByMatterId(matterEntity.getId(), context);
        MatterChargesEntity matterChargesEntity = new MatterChargesEntity();
        matterChargesEntity.initAttrValue();
        matterChargesEntity.setContent(sfbzMap.getOrDefault("sfbz", ""));
        matterChargesEntity.setMatterId(matterEntity.getId());
        matterChargesEntity.setMatterCode(matterEntity.getMatterNo());
        matterChargesEntity.setMatterName(matterEntity.getMatterName());
        matterChargesEntity.setSource(SourceEnum.政务网.getValue());
        matterChargesEntity.setCreateTime(new Date());
        matterChargesEntity.setCreateUser("system");
        matterChargesEntity.setCreateUserId(1L);
        matterChargesService.save(matterChargesEntity);
    }

    private void savebaseInfo(MatterEntity matterEntity, Document dom, Setting baseInfoSetting) {
        Map<String, String> baseInfoMap = MatterDetailHtmlParseUtil.getbaseInfoMapByHtml(dom);
        List<MatterExtEntity> matterExtEntities = new ArrayList<>();
        long sortN = 1;
        for (Map.Entry<String, String> m : baseInfoMap.entrySet()) {
            String value = baseInfoSetting.getOrDefault(m.getKey(), "");
            if (!ObjectUtils.isEmpty(value)) {
                if (!ObjectUtils.isEmpty(m.getValue()) && !"无".equals(m.getValue())) {
                    try {
                        ReflectUtil.setFieldValue(matterEntity, value, m.getValue());
                    } catch (Exception e) {
                        log.error(String.format("设置值异常！key:%s,value:%s,orginKey:%s", value, m.getValue(), m.getKey()));
                    }
                }
            } else {
                //未配置的属性映射添加到扩展表中
                //属性保存到扩展表中
                MatterExtEntity matterExtEntity = new MatterExtEntity();
                matterExtEntity.initAttrValue();
                matterExtEntity.setMatterId(matterEntity.getId());
                matterExtEntity.setMatterCode(matterEntity.getMatterNo());
                matterExtEntity.setFieldName(m.getKey());
                matterExtEntity.setFieldValue(m.getValue());
                matterExtEntity.setFieldOrderNo(sortN);
                matterExtEntity.setSource(SourceEnum.政务网.getValue());
                matterExtEntity.setCreateTime(new Date());
                matterExtEntity.setCreateUserId(1L);
                matterExtEntities.add(matterExtEntity);
                sortN++;
            }
        }

        if (!ObjectUtils.isEmpty(matterExtEntities)) {
            matterExtService.save(matterExtEntities, null);
        }

    }

    private void saveBllcInfo(MatterEntity matterEntity, Context context, Document dom) {
        List<Map<String, Object>> bllcMapList = MatterDetailHtmlParseUtil.getbllcMapByHtml(dom);
        matterFlowlimitService.deleteByMatterId(matterEntity.getId(), context);
        List<MatterFlowlimitEntity> flowlimitEntityArrayList = new ArrayList<>();
        for (Map<String, Object> bllcMap : bllcMapList) {
            MatterFlowlimitEntity matterFlowlimitEntity = new MatterFlowlimitEntity();
            matterFlowlimitEntity.initAttrValue();
            matterFlowlimitEntity.setMatterId(matterEntity.getId());
            matterFlowlimitEntity.setMatterCode(matterEntity.getMatterNo());
            matterFlowlimitEntity.setMatterName(matterEntity.getMatterName());
            matterFlowlimitEntity.setSource(SourceEnum.政务网.getValue());
            matterFlowlimitEntity.setCreateTime(new Date());
            matterFlowlimitEntity.setCreateUser("system");
            matterFlowlimitEntity.setCreateUserId(1L);

            bllcMap.entrySet().stream().forEach(m -> {
                if ("办理流程".equals(m.getKey().trim())) {
                    matterFlowlimitEntity.setFlowName(m.getValue().toString());
                }
                if ("办理时长".equals(m.getKey().trim())) {
                    matterFlowlimitEntity.setFlowTime(m.getValue().toString());
                }
                if ("转外时限".equals(m.getKey().trim())) {
                    matterFlowlimitEntity.setFlowLimit(m.getValue().toString());
                }
                if ("办理流程说明".equals(m.getKey().trim())) {
                    matterFlowlimitEntity.setFlowDesc(m.getValue().toString());
                }
            });
            flowlimitEntityArrayList.add(matterFlowlimitEntity);
        }
        matterFlowlimitService.save(flowlimitEntityArrayList);
    }

    private void saveSltjInfo(MatterEntity matterEntity, Context context, Document dom) {
        matterAcceptService.deleteByMatterId(matterEntity.getId(), context);
        Map<String, String> sltjMap = MatterDetailHtmlParseUtil.getSltjMapByHtml(dom);
        MatterAcceptEntity matterAcceptEntity = new MatterAcceptEntity();
        matterAcceptEntity.initAttrValue();
        matterAcceptEntity.setContent(sltjMap.getOrDefault("sltj", ""));
        matterAcceptEntity.setMatterId(matterEntity.getId());
        matterAcceptEntity.setMatterCode(matterEntity.getMatterNo());
        matterAcceptEntity.setMatterName(matterEntity.getMatterName());
        matterAcceptEntity.setSource(SourceEnum.政务网.getValue());
        matterAcceptEntity.setCreateTime(new Date());
        matterAcceptEntity.setCreateUser("system");
        matterAcceptEntity.setCreateUserId(1L);
        matterAcceptService.save(matterAcceptEntity);
    }

    private void saveDatumInfo(MatterEntity matterEntity, Context context, Document dom, Setting sqclInfoSetting) {
        Long[] datumIds = matterDatumService.find(new MatterDatumQuery().matterId(matterEntity.getId()).source(SourceEnum.政务网.getValue())).stream().map(item -> item.getId()).toArray(Long[]::new);
        if (!ObjectUtils.isEmpty(datumIds)) {
            matterDatumService.remove(datumIds, context);
            Long[] datumFileIds = matterDatumFileService.find(new MatterDatumFileQuery().datumIdList(Arrays.asList(datumIds))).stream().map(item -> item.getId()).toArray(Long[]::new);
            if (!ObjectUtils.isEmpty(datumFileIds)) {
                matterDatumFileService.remove(datumFileIds, context);
            }
        }

        List<Map<String, Object>> sqclList = MatterDetailHtmlParseUtil.getsqclInfoMapByHtml(dom);
        for (Map<String, Object> sqclMap : sqclList) {
            Map<String, String> baseinfoMap = (HashMap<String, String>) sqclMap.get("baseinfo");
            List<MatterDatumFileEntity> blankList = (List<MatterDatumFileEntity>) sqclMap.get("blankList");
            List<MatterDatumFileEntity> sampleList = (List<MatterDatumFileEntity>) sqclMap.get("sampleList");

            MatterDatumEntity datumEntity = new MatterDatumEntity();
            datumEntity.initAttrValue();
            datumEntity.setMatterId(matterEntity.getId());
            datumEntity.setMatterCode(matterEntity.getMatterNo());
            datumEntity.setMatterName(matterEntity.getMatterName());
            datumEntity.setMaterialName(matterEntity.getMatterName());
            datumEntity.setSource(SourceEnum.政务网.getValue());
            datumEntity.setCreateTime(new Date());
            datumEntity.setCreateUser("system");
            datumEntity.setCreateUserId(1L);
            //材料详情
            baseinfoMap.entrySet().stream().forEach(m -> {
                String value = sqclInfoSetting.getOrDefault(m.getKey(), "");
                if (!ObjectUtils.isEmpty(value)) {
                    try {
                        ReflectUtil.setFieldValue(datumEntity, value, m.getValue());
                    } catch (Exception e) {
                        log.error(String.format("设置值异常！key:%s,value:%s", value, m.getValue()));
                    }
                }
            });
            matterDatumService.save(datumEntity);

            //示例样表
            if (!ObjectUtils.isEmpty(sampleList)) {
                sampleList.forEach(fileEntity -> {
                    fileEntity.setDatumId(datumEntity.getId());
                    fileEntity.setMatterCode(matterEntity.getMatterNo());
                    fileEntity.setMaterialName(datumEntity.getMaterialName());
                });
            }
            matterDatumFileService.save(sampleList);

            //空白样表
            if (!ObjectUtils.isEmpty(blankList)) {
                blankList.forEach(fileEntity -> {
                    fileEntity.setDatumId(datumEntity.getId());
                    fileEntity.setMatterCode(matterEntity.getMatterNo());
                    fileEntity.setMaterialName(datumEntity.getMaterialName());
                });
            }
            matterDatumFileService.save(blankList);
        }
    }


}